@@ -85,6 +85,10 @@ GBLauthors[2] = {
 "August 2006\n"
 "- the pretty 'new folder' icon (replaced with kearone's version in 0.8)\n"
 "\n"
+"Javier Navarro\n"
+"November 2023\n"
+"- fixed El Torito sector count\n"
+"\n"
 "Packages:\n"
 "\n"
 "David Johnson\n"
